@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute the TF-IDF measure for ngram phrases
 
-our $VERSION = '0.0203';
+our $VERSION = '0.0204';
 
 use Moo;
 use strictures 2;
@@ -73,6 +73,9 @@ sub _process_ngrams {
         my @p = grep { $_ } split /\s/, $p;
         next unless @p == $size;
 
+        # Skip a lone single quote (allowed above)
+        next if grep { $_ eq "'" } @p;
+
         $hash->{$p} = $phrase->{$p};
     }
 
@@ -145,7 +148,7 @@ Text::TFIDF::Ngram - Compute the TF-IDF measure for ngram phrases
 
 =head1 VERSION
 
-version 0.0203
+version 0.0204
 
 =head1 SYNOPSIS
 
@@ -168,6 +171,9 @@ The TF-IDF ("term frequency-inverse document frequency") measure is used in
 information retrieval and text mining.  It is a statistical measure used to see
 how important a word is in a document or collection of documents.
 
+For a full example program, please see the F<eg/analyze> file in the
+distribution.
+
 =head1 ATTRIBUTES
 
 =head2 files
